@@ -4,9 +4,9 @@ from dataclasses import dataclass, field
 from functools import partial
 from typing import Any, List, Optional, Tuple
 
-import mkapi.core.markdown
+import mkapi.core.preprocess
 from mkapi.core.docstring import Docstring, parse_docstring
-from mkapi.core.signature import Signature
+from mkapi.core.inspect import Signature
 
 ISFUNCTIONS = {}
 for x in dir(inspect):
@@ -51,7 +51,7 @@ class Node:
     def get_markdown(self):
         markdowns = []
         for x in self:
-            markdowns.append(mkapi.core.markdown.convert(x.markdown))
+            markdowns.append(mkapi.core.preprocess.convert(x.markdown))
         return "\n\n<!-- mkapi:sep -->\n\n".join(markdowns)
 
     def set_html(self, html: str):
@@ -89,15 +89,21 @@ def get_sourcefile_and_lineno(obj) -> Tuple[str, int]:
 
 
 def filter(obj, sourcefile, lineno, qualname) -> bool:
-    if not get_kinds(obj):
+    if isinstance(obj, property):
+        return True
+    kinds = get_kinds(obj)
+    if not qualname and 'dataclass' in kinds:
+        return True
+    if not kinds:
         return False
+
     try:
         sourcefile_, lineno_ = get_sourcefile_and_lineno(obj)
     except Exception:
         return False
     if not hasattr(obj, "__qualname__"):
         return False
-    if obj.__qualname__.startswith(qualname):
+    if qualname and obj.__qualname__.startswith(qualname):
         return True
     if sourcefile_ is None:
         return False
@@ -108,6 +114,8 @@ def filter(obj, sourcefile, lineno, qualname) -> bool:
 
 
 def ignore_name(name: str) -> bool:
+    if name == '__init__':
+        return False
     if name.startswith("_"):
         return True
     return False
@@ -167,7 +175,7 @@ def get_attr(path: str):
 def get_object(name: str):
     try:
         return get_attr(name)
-    except (ModuleNotFoundError, AttributeError):
+    except (ModuleNotFoundError, AttributeError, ValueError):
         return importlib.import_module(name)
 
 
